using Microsoft.AspNetCore.Mvc;
using System;
using WebApplication1.Services;

namespace WebApplication1.Controllers
{
    public class ItemInventoryController : Controller
    {
        private readonly ItemService _itemService;

        public ItemInventoryController(ItemService itemService)
        {
            _itemService = itemService;
        }

        // 初期処理
        public IActionResult Index()
        {
            // 権限チェック
            // ここに共通権限チェックのロジックを実装する

            // 保管場所の取得とセット
            var storageLocations = _itemService.InitializeStorageLocations();
            ViewBag.StorageLocations = storageLocations;

            return View();
        }

        // 検索ボタン
        [HttpPost]
        public IActionResult Search(string itemCodeSearch, int storageLocationSearch)
        {
            // 入出庫情報を検索し、時点在庫の算出を行い、一覧表示する
            var inventoryList = _itemService.SearchInventory(itemCodeSearch, storageLocationSearch, DateTime.Now);
            return View("Index", inventoryList);
        }

        // 品目コードアンカークリック
        public IActionResult RedirectToItemMaster(int itemID)
        {
            // マスター管理システムの品目マスターを表示する
            // 実際のリダイレクト先URLは仮のもので、実際のURLに置き換える必要がある
            return Redirect($"http://itemmaster.example.com/{itemID}");
        }

        // 入出庫処理
        public IActionResult InOutProcessing(int itemID)
        {
            // 隠し項目の品目IDをパラメータとして渡し例外入出庫画面を表示する
            // 実際のリダイレクト先URLは仮のもので、実際のURLに置き換える必要がある
            return Redirect($"http://inoutprocessing.example.com/{itemID}");
        }
    }
}