using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.EntityFrameworkCore;
using WebApplication1.Models;

namespace WebApplication1.Repositories
{
    public class ItemRepository
    {
        private readonly DbContext _context;

        public ItemRepository(DbContext context)
        {
            _context = context;
        }

        // 保管場所テーブルより、全ての保管場所取得する。
        public List<StorageLocationModel> GetAllStorageLocations()
        {
            return _context.Set<StorageLocationModel>().ToList();
        }

        // 品目テーブルを検索する。
        public List<ItemModel> SearchItems(string itemCode)
        {
            return _context.Set<ItemModel>()
                .Where(item => item.ITEM_CODE.Contains(itemCode))
                .ToList();
        }

        // 月初在庫テーブルを検索し数量を取得する。
        public int GetBeginningOfMonthInventory(int itemId, int storageLocationId, DateTime currentDate)
        {
            var beginningOfMonth = new DateTime(currentDate.Year, currentDate.Month, 1);
            return _context.Set<MonthlyStockModel>()
                .Where(ms => ms.ITEM_ID == itemId && ms.STORAGE_LOCATION_ID == storageLocationId && ms.MONTH_OF_COLLECTION == beginningOfMonth.Month)
                .Select(ms => ms.QUANTITY)
                .FirstOrDefault();
        }

        // 入出庫テーブルから数量を取得する。
        public int GetTransactionQuantity(int itemId, int transactionType, DateTime startDate, DateTime endDate)
        {
            return _context.Set<IncomingShipmentDataModel>()
                .Where(isd => isd.ITEM_ID == itemId && isd.TRANSACTION_TYPE == transactionType && isd.TRANSACTION_DATE >= startDate && isd.TRANSACTION_DATE <= endDate)
                .Sum(isd => isd.TRANSACTION_QUANTITY);
        }
    }
}