using System;
using System.Collections.Generic;
using System.Linq;
using WebApplication1.Models;
using WebApplication1.Repositories;

namespace WebApplication1.Services
{
    public class ItemService
    {
        private readonly ItemRepository _itemRepository;

        public ItemService(ItemRepository itemRepository)
        {
            _itemRepository = itemRepository;
        }

        // 初期処理を行う
        public List<StorageLocationModel> InitializeStorageLocations()
        {
            // 保管場所の取得
            return _itemRepository.GetAllStorageLocations();
        }

        // 入出庫情報を検索し、時点在庫の算出を行い、一覧表示する
        public List<dynamic> SearchInventory(string itemCode, int storageLocationId, DateTime currentDate)
        {
            // 品目テーブルを検索する
            var items = _itemRepository.SearchItems(itemCode);

            var inventoryList = new List<dynamic>();
            foreach (var item in items)
            {
                // 月初在庫テーブルを検索し数量を取得する
                var beginningOfMonthInventory = _itemRepository.GetBeginningOfMonthInventory(item.ID, storageLocationId, currentDate);

                // 入出庫テーブルから数量を取得する
                var previousDay = currentDate.AddDays(-1);
                var beginningOfMonth = new DateTime(currentDate.Year, currentDate.Month, 1);
                var previousDayStockNumber = currentDate.Day == 1 ? 0 :
                    _itemRepository.GetTransactionQuantity(item.ID, 1, beginningOfMonth, previousDay);
                var previousDayDispatchNumber = currentDate.Day == 1 ? 0 :
                    _itemRepository.GetTransactionQuantity(item.ID, 2, beginningOfMonth, previousDay);
                var currentStockNumber = _itemRepository.GetTransactionQuantity(item.ID, 1, currentDate, currentDate);
                var currentDispatchNumber = _itemRepository.GetTransactionQuantity(item.ID, 2, currentDate, currentDate);

                // 現在在庫数を算出する
                var currentInventory = (beginningOfMonthInventory + previousDayStockNumber + currentStockNumber) - (previousDayDispatchNumber + currentDispatchNumber);

                inventoryList.Add(new
                {
                    ItemID = item.ID,
                    ItemCode = item.ITEM_CODE,
                    ItemName = item.ITEM_NAME,
                    ItemType2 = item.ITEM_CATEGORY_ID,
                    MainTradingPartner = item.SUPPLIER_CODE.ToString(), // 仕入先コードを主要取引先として扱う
                    CompanyPurchase = "", // 空文字
                    BeginningOfMonthInventory = beginningOfMonthInventory,
                    PreviousDayStockNumber = previousDayStockNumber,
                    PreviousDayDispatchNumber = previousDayDispatchNumber,
                    CurrentStockNumber = currentStockNumber,
                    CurrentDispatchNumber = currentDispatchNumber,
                    CurrentInventory = currentInventory
                });
            }

            // 取得したデータを画面に返却する
            return inventoryList;
        }
    }
}