package com.example.controller;

import com.example.form.InventorySearchForm;
import com.example.service.InventoryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.servlet.ModelAndView;

/**
 * 品目在庫管理一覧画面のコントローラ
 */
@Controller
public class InventoryController {

    @Autowired
    private InventoryService inventoryService;

    /**
     * 初期表示処理
     */
    @GetMapping("/inventory")
    public ModelAndView init(ModelAndView mav) {
        // TODO: 権限チェックと保管場所の取得処理を実装する
        mav.setViewName("inventory");
        return mav;
    }

    /**
     * 検索処理
     */
    @PostMapping("/inventory/search")
    public ModelAndView search(@Validated InventorySearchForm form, BindingResult bindingResult, ModelAndView mav) {
        if (bindingResult.hasErrors()) {
            // フォームのバリデーションエラーがある場合は初期画面に戻る
            mav.setViewName("inventory");
            return mav;
        }

        try {
            // 在庫情報の検索処理を実行
            mav.addObject("items", inventoryService.searchInventory(form.getItemCodeSearch(), Long.parseLong(form.getStorageLocationSearch())));
        } catch (Exception e) {
            // ビジネスロジックでのエラー処理
            mav.addObject("error", "在庫情報の検索に失敗しました。");
        }

        mav.setViewName("inventory");
        return mav;
    }
}