package com.example.repository;

import com.example.entity.IncomingShipmentDataEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;

import java.util.Date;
import java.util.List;

/**
 * 入出庫テーブルにアクセスするためのリポジトリ
 */
public interface IncomingShipmentDataRepository extends JpaRepository<IncomingShipmentDataEntity, Long> {

    /**
     * 品目IDと保管場所IDを条件に月初在庫テーブルを検索し数量を取得するクエリ
     */
    @Query("SELECT SUM(isd.transactionQuantity) FROM IncomingShipmentDataEntity isd " +
           "WHERE isd.itemId = :itemId AND isd.transactionLocation = :storageLocationId " +
           "AND isd.transactionDate >= :startOfMonth AND isd.transactionDate <= :endOfPreviousDay " +
           "AND isd.transactionType = :transactionType")
    Integer findQuantityByItemIdAndStorageLocationIdAndTransactionTypeBetweenDates(
            @Param("itemId") Long itemId,
            @Param("storageLocationId") Long storageLocationId,
            @Param("startOfMonth") Date startOfMonth,
            @Param("endOfPreviousDay") Date endOfPreviousDay,
            @Param("transactionType") Integer transactionType);
}