from django.db import models

class Item(models.Model):
    # 品目テーブル
    id = models.AutoField(primary_key=True, db_column='ID')
    item_code = models.CharField(max_length=32, db_column='ITEM_CODE', unique=True)
    item_name = models.CharField(max_length=32, db_column='ITEM_NAME')
    item_category_id = models.CharField(max_length=20, db_column='ITEM_CATEGORY_ID', blank=True, null=True)
    manufacturer = models.CharField(max_length=50, db_column='MANUFACTURER', blank=True, null=True)
    supplier_code = models.ForeignKey('Supplier', on_delete=models.CASCADE, db_column='SUPPLIER_CODE')
    unit_of_measure = models.IntegerField(db_column='UNIT_OF_MEASURE', blank=True, null=True)
    base_price = models.DecimalField(max_digits=10, decimal_places=2, db_column='BASE_PRICE', blank=True, null=True)
    safety_stock = models.IntegerField(db_column='SAFETY_STOCK', blank=True, null=True)
    lead_time = models.IntegerField(db_column='LEAD_TIME', blank=True, null=True)
    last_updated_date = models.DateField(auto_now=True, db_column='LAST_UPDATED_DATE')
    last_updated_by = models.CharField(max_length=32, db_column='LAST_UPDATED_BY', blank=True, null=True)

    class Meta:
        db_table = 'ITEM'

class IncomingShipmentData(models.Model):
    # 入出庫テーブル
    id = models.AutoField(primary_key=True, db_column='ID')
    transaction_type = models.IntegerField(db_column='TRANSACTION_TYPE')
    transaction_date = models.DateTimeField(db_column='TRANSACTION_DATE')
    item = models.ForeignKey(Item, on_delete=models.CASCADE, db_column='ITEM_ID')
    transaction_quantity = models.IntegerField(db_column='TRANSACTION_QUANTITY')
    transaction_location = models.IntegerField(db_column='TRANSACTION_LOCATION')
    transaction_reason = models.CharField(max_length=256, db_column='TRANSACTION_REASON', blank=True, null=True)

    class Meta:
        db_table = 'INCOMING_SHIPMENT_DATA'

class StorageLocation(models.Model):
    # 保管場所テーブル
    id = models.AutoField(primary_key=True, db_column='ID')
    storage_location_code = models.CharField(max_length=10, db_column='STORAGE_LOCATION_CODE', unique=True)
    storage_location_name = models.CharField(max_length=50, db_column='STORAGE_LOCATION_NAME')
    storage_location_type = models.CharField(max_length=1, db_column='STORAGE_LOCATION_TYPE')
    storage_capacity = models.IntegerField(db_column='STORAGE_CAPACITY', blank=True, null=True)
    location_address = models.CharField(max_length=50, db_column='LOCATION_ADDRESS', blank=True, null=True)
    manager = models.CharField(max_length=16, db_column='MANAGER', blank=True, null=True)
    notes = models.CharField(max_length=256, db_column='NOTES', blank=True, null=True)
    last_updated_date = models.DateTimeField(auto_now=True, db_column='LAST_UPDATED_DATE')
    last_updated_by = models.CharField(max_length=32, db_column='LAST_UPDATED_BY', blank=True, null=True)

    class Meta:
        db_table = 'STORAGE_LOCATION'

class MonthlyStock(models.Model):
    # 月初在庫テーブル
    id = models.AutoField(primary_key=True, db_column='ID')
    item = models.ForeignKey(Item, on_delete=models.CASCADE, db_column='ITEM_ID')
    month_of_collection = models.IntegerField(db_column='MONTH_OF_COLLECTION')
    storage_location = models.ForeignKey(StorageLocation, on_delete=models.CASCADE, db_column='STORAGE_LOCATION_ID')
    quantity = models.IntegerField(db_column='QUANTITY')

    class Meta:
        db_table = 'MONTHLY_STOCK'